@@ -308,7 +308,7 @@ def WriteConfig():
 
     f=data.configFolder+data.ConfigFile
     if(data.debug==True): print "Save configuration ("+f+")"
-    if (not os.path.exists(data.configFolder)):
+    if (not os.path.exists(str(data.configFolder))):
         print "Create configuration folder: ", data.configFolder
         os.mkdir(data.configFolder)
     try:
